maybe_note_label

Function maybe_note_label 

pub fn maybe_note_label(label: &str)
Use to note a discovered label to support label-derived refererence numbers Can by used by \label, among others. Note we only record the label if it hasn’t already been peeked, and consumed.