NewCounterOptions

Struct NewCounterOptions 

pub struct NewCounterOptions<'ct> {
    pub idprefix: &'ct str,
    pub idwithin: &'ct str,
    pub nested: Vec<&'ct str>,
}
configuration for new_counter

Fields

idprefix: &'ct str

specifies a prefix to be used in formatting ID’s for document structure elements counted by this counter. Ie. subsection 3 in section 2 might get: id=“S2.SS3”

idwithin: &'ct str

specifies that the ID is composed from $idwithin’s ID,, even though the counter isn’t numbered within it. (mainly to avoid duplicated ids)

nested: Vec<&'ct str>

a list of counters that correspond to scopes which are “inside” this one. Whenever any definitions scoped to this counter are deactivated, the inner counter’s scopes are also deactivated.